@@ -91,7 +91,7 @@ class EventFramework(_EventFramework):
 
         # workers
         self.workers = []
-        self.default_worker = self.addWorker()
+        self.default_worker = self.addWorker('default_worker')
         self.workers[0].addTask(Task(self.update, times=Task.CIRCLE))
 
         # 外部组件
