@@ -63,7 +63,7 @@ class EventStation(EventQueue):
                and self.filter == other.filter and self.respond == other.respond
 
     def __str__(self):
-        txt = f"estation: {self.key}<worker={self._worker}>"
+        txt = f"estation: {self.key}[worker={self._worker}]"
         return txt
 
     def __repr__(self):
