@@ -114,7 +114,7 @@ class Event:
     *6.STATE_EXCEPT - exception
         The event has an error in any step, which is passed through Event.trace for more error information
     """
-    def __init__(self, source:Any=None, dest:Any=None, task:Any=None, tags=(), times:int=EVENT_ALL):
+    def __init__(self, source:Any=None, dest:Any=None, task:Any=None, tags:list=None, times:int=EVENT_ALL):
         """
 
         :param source:
@@ -130,7 +130,7 @@ class Event:
         self.result = {}
         self.source = source
         self.dest = dest
-        self.tags = tags
+        self.tags = tags if tags is not None else ()
         self.state = STATE_OFFLINE
         self.times = times
         self.links:int = 0
@@ -203,8 +203,9 @@ class Event:
                 _: 0.1
         :return: bool
         """
-        if timeout:
-            end_point:float = timeout if timeout else inf
+        if timeout is not None:
+            end_point:float = timeout + time.time() if timeout else inf
+        print(self.state is not state)
         while self.state is not state:
             if timeout and time.time() > end_point:
                 return False
@@ -228,13 +229,18 @@ class Event:
             else:
                 self.state = STATE_RETIRED
 
-    def getResult(self, station_key: object)->object:
+    def getResult(self, station_key: object=None)->object:
         """
-        get the result of event from station
+        get the result of event from station. return Get or None
         :param station_key: object
+                _: None  mean get the only result
         :return: object
         """
-        return self.result.get(station_key)
+        if station_key is not None:
+            return self.result.get(station_key)
+        else:
+            get = list(self.result.values())
+            return get[0] if get else None
 
     # def record(self):
     #     """
